#!/usr/bin/env node
/* global cd, config, cp, echo, env, exec, exit, target */

/**
 * Build system.
 * @module bin.make
 */
'use strict';

// Module dependencies.
require('shelljs/make');
var path=require('path');
var util=require('util');

/**
 * Provides tasks for [ShellJS](http://shelljs.org) make tool.
 * @class cli.Makefile
 * @static
 */
cd(__dirname+'/..');

/**
 * The application settings.
 * @property config
 * @type Object
 */
config.fatal=true;

/**
 * Runs the default tasks.
 * @method all
 */
target.all=function() {
  echo('Please specify a target. Available targets:');
  for(var task in target) {
    if(task!='all') echo(' ', task);
  }
};

/**
 * Builds the documentation.
 * @method doc
 */
target.doc=function() {
  echo('Build the documentation...');
  exec('yuidoc-bs --extension ".dart" --theme lumen');
  cp('-f', [ 'www/apple-touch-icon.png', 'www/favicon.ico' ], 'doc/api/assets');
};

/**
 * Performs static analysis of source code.
 * @method lint
 */
target.lint=function() {
  config.fatal=false;

  echo('Static analysis of JavaScript sources...');
  exec('jshint --exclude bin/packages --verbose bin');

  echo('Static analysis of documentation comments...');
  exec('yuidoc-bs --extension ".dart" --lint');

  config.fatal=true;
};

/**
 * Runs the unit tests.
 * @method test
 */
target.test=function() {
  var program=require('commander');
  program._name='make test';
  
  program
    .version(require('../package.json').version)
    .option('-k, --key <apiKey>', 'the Akismet API key')
    .option('-b, --blog <uri>', 'the front page or home URL [http://dev.belin.io/akismet.dart]', 'http://dev.belin.io/akismet.dart')
    .parse(process.argv);

  if(!program.key) program.help();
  
  echo('Run the unit tests...');
  if(!('DART_SDK' in env)) {
    echo('Unable to locate "dart" program: DART_SDK environment variable not set.');
    exit(1);
  }

  var result=exec(util.format(
    '"%s" "%s" %s %s',
    path.join(env.DART_SDK, 'bin/dart'),
    path.resolve('test/io_test.dart'),
    program.key,
    program.blog
  ));
  
  exit(result.code);
};
