/**
 * Implementation of the `akismet.core.Author` class.
 * @module core.author
 */
part of akismet.core;

/**
 * Represents the author of a comment.
 * @class akismet.core.Author
 * @constructor
 * @param {String} [name] The author's name.
 * @param {String} [email] The author's mail address.
 */
class Author {

  Author([ this.name, this.email ]);

  /**
   * Creates a new instance from the specified map in JSON format.
   * @method fromJson
   * @param {Map&lt;String, String&gt;} map A map in JSON format specifying the object properties.
   * @return {akismet.core.Author} The author corresponding to the specified map.
   * @static
   */
  Author.fromJson(Map<String, String> map) {
    assert(map!=null);

    if(map['comment_author']!=null) name=map['comment_author'];
    if(map['comment_author_email']!=null) email=map['comment_author_email'];
    if(map['comment_author_url']!=null) url=Uri.parse(map['comment_author_url']);
    if(map['user_agent']!=null) userAgent=map['user_agent'];
    if(map['user_ip']!=null) ipAddress=map['user_ip'];
  }

  /**
   * The author's mail address.
   * @property email
   * @type String
   */
  String email;

  /**
   * The author's IP address.
   * @property ipAddress
   * @type String
   */
  String ipAddress;

  /**
   * The author's name.
   * @property name
   * @type String
   */
  String name;

  /**
   * The URL of the author's website.
   * @property url
   * @type Uri
   */
  Uri url;

  /**
   * The author's user agent, that is the string identifying the Web browser used to submit comments.
   * @property userAgent
   * @type String
   */
  String userAgent;

  /**
   * Converts this object to a map in JSON format.
   * @method toJson
   * @return {Map&lt;String, String&gt;} The map in JSON format corresponding to this object.
   */
  Map<String, String> toJson() {
    var map={};

    if(name!=null) map['comment_author']=name;
    if(email!=null) map['comment_author_email']=email;
    if(url!=null) map['comment_author_url']=url.toString();
    if(userAgent!=null) map['user_agent']=userAgent;
    if(ipAddress!=null) map['user_ip']=ipAddress;

    return map;
  }

  /**
   * Returns a string representation of this object.
   * @method toString
   * @return {String} A string that represents the current object.
   */
  @override
  String toString() => 'Author ${toJson()}';
}