/**
 * Implementation of the `akismet.tests.core.AuthorTest` class.
 * @module tests.core.author_test
 */
part of akismet.tests.core;

/**
 * Tests the features of `akismet.core.Author` class.
 * @class akismet.tests.core.AuthorTest
 * @constructor
 */
class AuthorTest {

  /**
   * Runs the unit tests.
   * @method run
   */
  void run() {
    group('Author', () {
      test('fromJson()', testFromJson);
      test('toJson()', testToJson);
    });
  }

  /**
   * Tests the `fromJson` constructor.
   * @method testFromJson
   */
  void testFromJson() {
    var author=new Author.fromJson(JSON.decode('{}'));
    expect(author.email, isNull);
    expect(author.url, isNull);

    author=new Author.fromJson(JSON.decode('{ "comment_author_email": "cedric@belin.io", "comment_author_url": "http://belin.io" }'));
    expect(author.email, equals('cedric@belin.io'));
    expect(author.url, equals(Uri.parse('http://belin.io')));
  }

  /**
   * Tests the `toJson` method.
   * @method testToJson
   */
  void testToJson() {
    var author=new Author();
    expect(JSON.encode(author), equals('{}'));

    author=new Author('Cédric Belin', 'cedric@belin.io')
      ..ipAddress='127.0.0.1'
      ..url=Uri.parse('http://belin.io');

    expect(JSON.encode(author), equals('{"comment_author":"Cédric Belin","comment_author_email":"cedric@belin.io","comment_author_url":"http://belin.io","user_ip":"127.0.0.1"}'));
  }
}
